@@ -1,4 +1,3 @@
-
 # wtite temporary DESCRIPTION with
 # * Imports: tb$source=="cran"
 # * Remotes:tb$source=="remote"
@@ -43,9 +42,11 @@ install <- function(
     ...
 ) {
     uto <- suppressWarnings(
-        as.integer(Sys.getenv("R_DEFAULT_INTERNET_TIMEOUT")))
-    if (is.na(uto))
+        as.integer(Sys.getenv("R_DEFAULT_INTERNET_TIMEOUT"))
+    )
+    if (is.na(uto)) {
         uto <- timeout
+    }
     oo <- options(timeout = max(uto, timeout, getOption("timeout")))
     on.exit(options(oo), add = TRUE)
     created <- file.exists(file.path(dir, file))
@@ -54,55 +55,67 @@ install <- function(
         if (ask && !file.exists(file.path(dir, file))) {
             return(invisible(NULL))
         } else {
-            if (cleanup)
+            if (cleanup) {
                 on.exit(unlink(dfile), add = TRUE)
+            }
         }
     }
     d <- jsonlite::fromJSON(read_lines(file.path(dir, file)))
-    p <- d$packages[!is.na(d$packages$source),]
+    p <- d$packages[!is.na(d$packages$source), ]
     r <- p$repos
     if (length(r) > 0L) {
         o <- getOption("repos")
         on.exit(options("repos" = o), add = TRUE)
         options("repos" = c(o, r))
     }
-    desc <- c("Imports:\n  ",
+    desc <- c(
+        "Imports:\n  ",
         paste(
             sort(p$package[p$source %in% c("cran", "remote")]),
-            collapse = ",\n  "))
+            collapse = ",\n  "
+        )
+    )
     if (any(p$source == "remote")) {
-        desc <- c(desc, "\nRemotes:\n  ",
+        desc <- c(
+            desc,
+            "\nRemotes:\n  ",
             paste(
                 sort(p$remote[p$source == "remote"]),
-                collapse = ",\n  "),
-            "\n")
+                collapse = ",\n  "
+            ),
+            "\n"
+        )
     }
     desc <- paste0(desc, collapse = "")
     tmpdir <- tempdir()
     writeLines(
         desc,
-        file.path(tmpdir, "DESCRIPTION"))
+        file.path(tmpdir, "DESCRIPTION")
+    )
     remotes::install_deps(
         pkgdir = tmpdir,
         upgrade = upgrade,
-        ...)
+        ...
+    )
 
-    inst_repo <- p[p$source == "repo",]
+    inst_repo <- p[p$source == "repo", ]
     for (re in unique(inst_repo$repo)) {
         remotes::install_cran(
             pkgs = inst_repo$package[inst_repo$repo == re],
             repos = re,
             upgrade = upgrade,
-            ...)
+            ...
+        )
     }
     inst_ver <- sort(p$package[p$source == "ver"])
-    inst_ver <- p[p$source == "ver",]
+    inst_ver <- p[p$source == "ver", ]
     for (i in seq_len(nrow(inst_ver))) {
         remotes::install_version(
             package = inst_ver$package[i],
             version = inst_ver$ver[i],
             upgrade = upgrade,
-            ...)
+            ...
+        )
     }
     invisible(NULL)
 }
